==> sptk-3.5.7.05.tbz2: sptk-3.5.7.05/sptk3/xml/CXmlDoc.h <==
/***************************************************************************
                          SIMPLY POWERFUL TOOLKIT (SPTK)
                          CXmlDoc.h  -  description
                             -------------------
    begin                : Sun May 22 2003
    based on the code    : Mikko Lahteenmaki <Laza@Flashmail.com>
    copyright            : (C) 2003 by Alexey Parshin. All rights reserved.
    email                : alexeyp@gmail.com
 ***************************************************************************/

/***************************************************************************
  Redistribution and use in source and binary forms, with or without 
  modification, are permitted provided that the following conditions are met:

  * Redistributions of source code must retain the above copyright notice, 
    this list of conditions and the following disclaimer.
  * Redistributions in binary form must reproduce the above copyright notice, 
    this list of conditions and the following disclaimer in the documentation 
    and/or other materials provided with the distribution.
  * Neither the name of the <ORGANIZATION> nor the names of its contributors 
    may be used to endorse or promote products derived from this software 
    without specific prior written permission.

  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
  A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER 
  OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
  EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
  PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
  PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
  LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
  NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
  SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 ***************************************************************************/

#ifndef __CXMLDOC_H__
#define __CXMLDOC_H__

#include <sptk3/xml/CXmlNode.h>
#include <sptk3/xml/CXmlDocType.h>
#include <sptk3/xml/CXmlElement.h>
#include <sptk3/CSharedStrings.h>
#include <sptk3/CBuffer.h>

#include <string>
#include <map>

namespace sptk {

/// @addtogroup XML
/// @{

/// @brief XML document.
///
/// Represents the entire XML document.
/// It provides access to document root node, which includes all nodes in XML document tree.
class CXmlDoc: public CSharedStrings, public CXmlElement {
    friend class CXmlNode;

    CXmlDocType     m_doctype;          ///< Document type
    static int      m_indent_spaces;    ///< Indent spaces
	CBuffer			m_encodeBuffer;		///< Buffer to encode entities

    static const std::string nodeNameString;

	static const std::string indentsString;	/// String of a indent spaces

	/// @brief Internal entities parser
	void parseEntities(char* entitiesSection);

	/// @brief Internal doctype parser
	void parseDocType(char* docTypeSection);

	/// @brief Internal attributes parser
	void processAttributes(CXmlNode* node,char *ptr);

protected:

    CBuffer         m_decodeBuffer;     ///< Decode and encode buffer

    /// Creates new named node of type CXmlNode::DOM_ELEMENT.
    /// It can be added to document DOM tree.
    /// @param tagname const char *, name of the element
    /// @see CXmlNode
    CXmlNode *createElement(const char *tagname);

public:

    /// Constructs an empty document, without doctype.
    CXmlDoc();

    /// Constructs an empty document, with doctype.
    /// @param name const char *, name of the document.
    /// @param public_id const char *, public id of the document, placed on DOCTYPE declaration
    /// @param system_id const char *, system id of the document, placed on DOCTYPE declaration
    CXmlDoc(const char *name, const char *public_id=0, const char *system_id=0);

    /// Destructor
    virtual ~CXmlDoc() {
        clear();
    }

    /// @brief Returns node type
    virtual CXmlNodeType type() const {
        return DOM_DOCUMENT;
    }

    /// Destroys all nodes in document
    virtual void clear();

    /// @brief Returns the node name.
    ///
    /// The meaning of the value depends on the node type
    virtual const std::string& name() const {
        return nodeNameString;
    }

    /// @brief Sets the new name for the node
    /// @param name const std::string&, new node name
    virtual void name(const std::string& name) {}

    /// @brief Sets new name for node
    /// @param name const char *, new node name
    virtual void name(const char *name) {}

    /// Returns doctype of document.
    /// You can use it to add e.g. custom entities.
    /// <pre>
    /// mydoc->doctype().set_entity("myentity", "myreplacement");
    /// </pre>
    CXmlDocType &docType() {
        return m_doctype;
    }

    /// Returns doctype of document.
    /// You can use it to add e.g. custom entities.
    /// <pre>
    /// mydoc->doctype().set_entity("myentity", "myreplacement");
    /// </pre>
    const CXmlDocType &docType() const {
        return m_doctype;
    }

    /// @brief Returns pointer to root element of document
    CXmlNode *rootNode();

    /// @brief Returns indentation in save
    static int indentSpaces() {
        return m_indent_spaces;
    }

    /// @brief Set indentation in save, defaults to 2
    ///
    /// @param i as new indent spaces
    static void indentSpaces(int i) {
        m_indent_spaces = i;
    }

    /// Loads document from buffer.
    /// @param buffer const CBuffer&, source buffer
    virtual void load(const CBuffer &buffer);

    /// Saves document to buffer.
    /// @param buffer CBuffer&, a buffer to save document
    /// @param indent int, how many indent spaces at start
    virtual void save(CBuffer &buffer, int indent=0) const;
};
/// @}
}
#endif

==> sptk-3.5.8.8.tbz2: sptk-3.5.8.8/sptk3/xml/CXmlDoc.h <==
/***************************************************************************
                          SIMPLY POWERFUL TOOLKIT (SPTK)
                          CXmlDoc.h  -  description
                             -------------------
    begin                : Sun May 22 2003
    based on the code    : Mikko Lahteenmaki <Laza@Flashmail.com>
    copyright            : (C) 2003 by Alexey Parshin. All rights reserved.
    email                : alexeyp@gmail.com
 ***************************************************************************/

/***************************************************************************
  Redistribution and use in source and binary forms, with or without
  modification, are permitted provided that the following conditions are met:

  * Redistributions of source code must retain the above copyright notice,
    this list of conditions and the following disclaimer.
  * Redistributions in binary form must reproduce the above copyright notice,
    this list of conditions and the following disclaimer in the documentation
    and/or other materials provided with the distribution.
  * Neither the name of the <ORGANIZATION> nor the names of its contributors
    may be used to endorse or promote products derived from this software
    without specific prior written permission.

  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
  A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER
  OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
  EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
  PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
  PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
  LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
  NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
  SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 ***************************************************************************/

#ifndef __CXMLDOC_H__
#define __CXMLDOC_H__

#include <sptk3/xml/CXmlNode.h>
#include <sptk3/xml/CXmlDocType.h>
#include <sptk3/xml/CXmlElement.h>
#include <sptk3/CSharedStrings.h>
#include <sptk3/CBuffer.h>

#include <string>
#include <map>

namespace sptk
{

/// @addtogroup XML
/// @{

/// @brief XML document.
///
/// Represents the entire XML document.
/// It provides access to document root node, which includes all nodes in XML document tree.
class CXmlDoc: public CSharedStrings, public CXmlElement
{
    friend class CXmlNode;

    CXmlDocType     m_doctype;          ///< Document type
    static int      m_indent_spaces;    ///< Indent spaces
    CBuffer         m_encodeBuffer;     ///< Buffer to encode entities

    static const std::string nodeNameString;

    static const std::string indentsString;     /// String of a indent spaces

    /// @brief Internal entities parser
    void parseEntities(char* entitiesSection);

    /// @brief Internal doctype parser
    void parseDocType(char* docTypeSection);

    /// @brief Internal attributes parser
    void processAttributes(CXmlNode* node, char *ptr);

protected:

    CBuffer         m_decodeBuffer;     ///< Decode and encode buffer

    /// Creates new named node of type CXmlNode::DOM_ELEMENT.
    /// It can be added to document DOM tree.
    /// @param tagname const char *, name of the element
    /// @see CXmlNode
    CXmlNode *createElement (const char *tagname);

public:

    /// Constructs an empty document, without doctype.
    CXmlDoc();

    /// Constructs an empty document, with doctype.
    /// @param name const char *, name of the document.
    /// @param public_id const char *, public id of the document, placed on DOCTYPE declaration
    /// @param system_id const char *, system id of the document, placed on DOCTYPE declaration
    CXmlDoc(const char *name, const char *public_id = 0, const char *system_id = 0);

    /// Destructor
    virtual ~CXmlDoc() {
        clear();
    }

    /// @brief Returns node type
    virtual CXmlNodeType type() const {
        return DOM_DOCUMENT;
    }

    /// Destroys all nodes in document
    virtual void clear();

    /// @brief Returns the node name.
    ///
    /// The meaning of the value depends on the node type
    virtual const std::string& name() const {
        return nodeNameString;
    }

    /// @brief Sets the new name for the node
    /// @param name const std::string&, new node name
    virtual void name(const std::string& name) {}

    /// @brief Sets new name for node
    /// @param name const char *, new node name
    virtual void name(const char *name) {}

    /// Returns doctype of document.
    /// You can use it to add e.g. custom entities.
    /// <pre>
    /// mydoc->doctype().set_entity("myentity", "myreplacement");
    /// </pre>
    CXmlDocType &docType() {
        return m_doctype;
    }

    /// Returns doctype of document.
    /// You can use it to add e.g. custom entities.
    /// <pre>
    /// mydoc->doctype().set_entity("myentity", "myreplacement");
    /// </pre>
    const CXmlDocType &docType() const {
        return m_doctype;
    }

    /// @brief Returns pointer to root element of document
    CXmlNode *rootNode();

    /// @brief Returns indentation in save
    static int indentSpaces() {
        return m_indent_spaces;
    }

    /// @brief Set indentation in save, defaults to 2
    ///
    /// @param i as new indent spaces
    static void indentSpaces(int i) {
        m_indent_spaces = i;
    }

    /// Loads document from buffer.
    /// @param buffer const char*, source buffer
    virtual void load(const char* buffer);

    /// Loads document from buffer.
    /// @param buffer const CBuffer&, source buffer
    virtual void load(const CBuffer& buffer) {
        load(buffer.c_str());
    }

    /// Saves document to buffer.
    /// @param buffer CBuffer&, a buffer to save document
    /// @param indent int, how many indent spaces at start
    virtual void save(CBuffer& buffer, int indent = 0) const;
};
/// @}
}
#endif
